Learn R Programming

COVIDIBGE (version 0.2.2)

read_covid: Read PNAD COVID19 microdata

Description

This function reads PNAD COVID19 microdata.

Usage

read_covid(microdata, vars = NULL)

Value

A tibble with selected variables of the microdata, including the necessary survey design ones.

Arguments

microdata

A comma-separated values file containing microdata from PNAD COVID19 survey, available on official website: (select a microdata file) - https://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_PNAD_COVID19/Microdados/Dados/.

vars

Vector of variable names to be kept for analysis. Default is to keep all variables.

See Also

get_covid for downloading, labeling, deflating and creating survey design object for PNAD COVID19 microdata.
covid_labeller for labeling categorical variables from PNAD COVID19 microdata.
covid_deflator for adding deflator variables to PNAD COVID19 microdata.
covid_design for creating PNAD COVID19 survey design object.
covid_example for getting the path of the PNAD COVID19 toy example files.

Examples

Run this code
data_path <- covid_example(path="exampledata.csv")
covid.df <- read_covid(microdata=data_path, vars=c("C001","C002"))

Run the code above in your browser using DataLab